@@ -2,8 +2,9 @@
 
 ### Default method.
 spmd.irecv.default <- function(x.buffer = NULL,
-    rank.source = .SPMD.CT$rank.source, tag = .SPMD.CT$tag,
-    comm = .SPMD.CT$comm, request = .SPMD.CT$request, status = .SPMD.CT$status){
+    rank.source = .pbd_env$SPMD.CT$rank.source, tag = .pbd_env$SPMD.CT$tag,
+    comm = .pbd_env$SPMD.CT$comm, request = .pbd_env$SPMD.CT$request,
+    status = .pbd_env$SPMD.CT$status){
   ### This implementation is the same as spmd.recv.default(), because
   ### a blocking probe should be evoked to get the length of object for
   ### preparing enough x.buffer.
@@ -13,24 +14,27 @@ spmd.irecv.default <- function(x.buffer = NULL,
 
 ### For irecv.
 spmd.irecv.integer <- function(x.buffer,
-    rank.source = .SPMD.CT$rank.source, tag = .SPMD.CT$tag,
-    comm = .SPMD.CT$comm, request = .SPMD.CT$request, status = .SPMD.CT$status){
+    rank.source = .pbd_env$SPMD.CT$rank.source, tag = .pbd_env$SPMD.CT$tag,
+    comm = .pbd_env$SPMD.CT$comm, request = .pbd_env$SPMD.CT$request,
+    status = .pbd_env$SPMD.CT$status){
   .Call("spmd_irecv_integer", x.buffer, as.integer(rank.source),
         as.integer(tag), as.integer(comm), as.integer(request),
         PACKAGE = "pbdMPI")
 } # End of spmd.irecv.integer().
 
 spmd.irecv.double <- function(x.buffer,
-    rank.source = .SPMD.CT$rank.source, tag = .SPMD.CT$tag,
-    comm = .SPMD.CT$comm, request = .SPMD.CT$request, status = .SPMD.CT$status){
+    rank.source = .pbd_env$SPMD.CT$rank.source, tag = .pbd_env$SPMD.CT$tag,
+    comm = .pbd_env$SPMD.CT$comm, request = .pbd_env$SPMD.CT$request,
+    status = .pbd_env$SPMD.CT$status){
   .Call("spmd_irecv_double", x.buffer, as.integer(rank.source),
         as.integer(tag), as.integer(comm), as.integer(request),
         PACKAGE = "pbdMPI")
 } # End of spmd.irecv.double().
 
 spmd.irecv.raw <- function(x.buffer,
-    rank.source = .SPMD.CT$rank.source, tag = .SPMD.CT$tag,
-    comm = .SPMD.CT$comm, request = .SPMD.CT$request, status = .SPMD.CT$status){
+    rank.source = .pbd_env$SPMD.CT$rank.source, tag = .pbd_env$SPMD.CT$tag,
+    comm = .pbd_env$SPMD.CT$comm, request = .pbd_env$SPMD.CT$request,
+    status = .pbd_env$SPMD.CT$status){
   .Call("spmd_irecv_raw", x.buffer, as.integer(rank.source),
         as.integer(tag), as.integer(comm), as.integer(request),
         PACKAGE = "pbdMPI")
