@@ -73,16 +73,16 @@ SEXP spmd_comm_get_parent(SEXP R_comm){
 			&global_spmd_comm[INTEGER(R_comm)[0]]))));
 } /* End of spmd_comm_get_parent(). */
 
-SEXP spmd_is_master(void){
+SEXP spmd_is_manager(void){
 	int check;
-	MPI_Comm master;
-	MPI_Comm_get_parent(&master);
-	check = (master == MPI_COMM_NULL);
+	MPI_Comm manager;
+	MPI_Comm_get_parent(&manager);
+	check = (manager == MPI_COMM_NULL);
 	if(! check){
-		 MPI_Comm_free(&master);
+		 MPI_Comm_free(&manager);
 	}
 	return(AsInt(check));
-} /* End of spmd_is_master(). */
+} /* End of spmd_is_manager(). */
 
 SEXP spmd_comm_abort(SEXP R_comm, SEXP R_errorcode){
 	return(AsInt(
